[PATCH 09/24] Rename IBlockBackstore and IBlockStorageObject

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

 



Signed-off-by: Andy Grover <agrover@xxxxxxxxxx>
---
 rtslib/__init__.py |    4 ++--
 rtslib/root.py     |    4 ++--
 rtslib/tcm.py      |   40 ++++++++++++++++++++--------------------
 3 files changed, 24 insertions(+), 24 deletions(-)

diff --git a/rtslib/__init__.py b/rtslib/__init__.py
index 9983c8e..18ad7bb 100644
--- a/rtslib/__init__.py
+++ b/rtslib/__init__.py
@@ -23,8 +23,8 @@ from utils import RTSLibError, RTSLibBrokenLink, RTSLibNotInCFS
 from target import LUN, MappedLUN
 from target import NodeACL, NetworkPortal, TPG, Target, FabricModule
 
-from tcm import FileIOBackstore, IBlockBackstore
-from tcm import FileIOStorageObject, IBlockStorageObject
+from tcm import FileIOBackstore, BlockBackstore
+from tcm import FileIOStorageObject, BlockStorageObject
 from tcm import PSCSIBackstore, RDMCPBackstore
 from tcm import PSCSIStorageObject, RDMCPStorageObject
 
diff --git a/rtslib/root.py b/rtslib/root.py
index 1e67b02..d405b5e 100644
--- a/rtslib/root.py
+++ b/rtslib/root.py
@@ -23,7 +23,7 @@ import glob
 
 from node import CFSNode
 from target import Target, FabricModule
-from tcm import FileIOBackstore, IBlockBackstore
+from tcm import FileIOBackstore, BlockBackstore
 from tcm import PSCSIBackstore, RDMCPBackstore
 from utils import RTSLibError, RTSLibBrokenLink, flatten_nested_list, modprobe
 
@@ -91,7 +91,7 @@ class RTSRoot(CFSNode):
                             PSCSIBackstore(int(regex.group(3)), 'lookup'))
                     elif regex.group(1) == "iblock":
                         backstores.add(
-                            IBlockBackstore(int(regex.group(3)), 'lookup'))
+                            BlockBackstore(int(regex.group(3)), 'lookup'))
                     elif regex.group(1) == "rd_mcp":
                         backstores.add(
                             RDMCPBackstore(int(regex.group(3)), 'lookup'))
diff --git a/rtslib/tcm.py b/rtslib/tcm.py
index 4ccd488..0b48d67 100644
--- a/rtslib/tcm.py
+++ b/rtslib/tcm.py
@@ -238,13 +238,13 @@ class FileIOBackstore(Backstore):
                                    size=size, wwn=wwn,
                                    buffered_mode=buffered_mode)
 
-class IBlockBackstore(Backstore):
+class BlockBackstore(Backstore):
     '''
     This is an interface to iblock backstore plugin objects in configFS.
     An IBlockBackstore object is identified by its backstore index.
     '''
 
     # IBlockBackstore private stuff
 
     def __init__(self, index, mode='any'):
         '''
@@ -255,20 +255,20 @@ class IBlockBackstore(Backstore):
             - I{'lookup'} the object MUST already exist configFS.
             - I{'create'} the object must NOT already exist in configFS.
         @type mode:string
-        @return: An IBlockBackstore object.
+        @return: A BlockBackstore object.
         '''
 
-        super(IBlockBackstore, self).__init__("block", IBlockStorageObject,
+        super(BlockBackstore, self).__init__("block", BlockStorageObject,
                                                index, mode, alt_dirprefix="iblock")
 
     # IBlockBackstore public stuff
 
     def storage_object(self, name, dev=None, wwn=None):
         '''
-        Same as IBlockStorageObject() without specifying the backstore
+        Same as BlockStorageObject() without specifying the backstore
         '''
         self._check_self()
-        return IBlockStorageObject(self, name=name, dev=dev, wwn=wwn)
+        return BlockStorageObject(self, name=name, dev=dev, wwn=wwn)
 
 class StorageObject(CFSNode):
     '''
@@ -871,12 +871,12 @@ class FileIOStorageObject(StorageObject):
     size = property(_get_size,
             doc="Get the current FileIOStorage size in bytes")
 
-class IBlockStorageObject(StorageObject):
+class BlockStorageObject(StorageObject):
     '''
-    An interface to configFS storage objects for iblock backstore.
+    An interface to configFS storage objects for block backstore.
     '''
 
     # IBlockStorageObject private stuff
 
     def __init__(self, backstore, name, dev=None, wwn=None):
         '''
@@ -906,20 +906,20 @@ class IBlockStorageObject(StorageObject):
         '''
 
         if dev is not None:
-            super(IBlockStorageObject, self).__init__(backstore,
-                                                      IBlockBackstore,
-                                                      name,
-                                                      'create')
+            super(BlockStorageObject, self).__init__(backstore,
+                                                     BlockBackstore,
+                                                     name,
+                                                     'create')
             try:
                 self._configure(dev, wwn)
             except:
                 self.delete()
                 raise
         else:
-            super(IBlockStorageObject, self).__init__(backstore,
-                                                      IBlockBackstore,
-                                                      name,
-                                                      'lookup')
+            super(BlockStorageObject, self).__init__(backstore,
+                                                     BlockBackstore,
+                                                     name,
+                                                     'lookup')
 
     def _configure(self, dev, wwn):
         self._check_self()
@@ -952,7 +952,7 @@ class IBlockStorageObject(StorageObject):
         self._check_self()
         return int(self._parse_info('Minor'))
 
     # IblockStorageObject public stuff
 
     major = property(_get_major,
             doc="Get the block device major number")
@@ -238,13 +238,13 @@ class FileIOBackstore(Backstore):
     '''
     This is an interface to iblock backstore plugin objects in configFS.
-    An IBlockBackstore object is identified by its backstore index.
+    A BlockBackstore object is identified by its backstore index.
     '''
 
@@ -238,13 +238,13 @@ class FileIOBackstore(Backstore):
     '''
 
-    # IBlockBackstore private stuff
+    # BlockBackstore private stuff
 
     def __init__(self, index, mode='any'):
@@ -255,20 +255,20 @@ class IBlockBackstore(Backstore):
                                                index, mode, alt_dirprefix="iblock")
 
-    # IBlockBackstore public stuff
+    # BlockBackstore public stuff
 
     def storage_object(self, name, dev=None, wwn=None):
@@ -871,12 +871,12 @@ class FileIOStorageObject(StorageObject):
     '''
 
-    # IBlockStorageObject private stuff
+    # BlockStorageObject private stuff
 
     def __init__(self, backstore, name, dev=None, wwn=None):
@@ -952,7 +952,7 @@ class IBlockStorageObject(StorageObject):
         return int(self._parse_info('Minor'))
 
-    # IblockStorageObject public stuff
+    # BlockStorageObject public stuff
 
     major = property(_get_major,
-- 
1.7.1

--
To unsubscribe from this list: send the line "unsubscribe target-devel" in
the body of a message to majordomo@xxxxxxxxxxxxxxx
More majordomo info at  http://vger.kernel.org/majordomo-info.html


[Index of Archives]     [Linux SCSI]     [Kernel Newbies]     [Linux SCSI Target Infrastructure]     [Share Photos]     [IDE]     [Security]     [Git]     [Netfilter]     [Bugtraq]     [Yosemite News]     [MIPS Linux]     [ARM Linux]     [Linux Security]     [Linux RAID]     [Linux ATA RAID]     [Linux IIO]     [Device Mapper]

  Powered by Linux